#!/bin/sh

echo Creating autoconf scripts...
autoreconf -i

echo Configuring...
./configure

sh ./makedist2.sh

